/**
 * DevExtreme (esm/renovation/ui/scheduler/common.js)
 * Version: 22.1.0 (build 21320-1002)
 * Build date: Tue Nov 16 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
import {
    utils
} from "../../../ui/scheduler/utils";
import {
    TimeZoneCalculator
} from "./timeZoneCalculator/utils";
import timeZoneUtils from "../../../ui/scheduler/utils.timeZone";
import {
    AppointmentFilterBaseStrategy,
    AppointmentFilterVirtualStrategy
} from "../../../ui/scheduler/appointments/dataProvider/appointmentFilter";
import {
    createExpressions
} from "../../../ui/scheduler/resources/utils";
import getPreparedDataItems from "./utils/data";
export var createDataAccessors = function(props) {
    var forceIsoDateParsing = arguments.length > 1 && void 0 !== arguments[1] ? arguments[1] : false;
    var dataAccessors = utils.dataAccessors.create({
        startDate: props.startDateExpr,
        endDate: props.endDateExpr,
        startDateTimeZone: props.startDateTimeZoneExpr,
        endDateTimeZone: props.endDateTimeZoneExpr,
        allDay: props.allDayExpr,
        text: props.textExpr,
        description: props.descriptionExpr,
        recurrenceRule: props.recurrenceRuleExpr,
        recurrenceException: props.recurrenceExceptionExpr
    }, null, forceIsoDateParsing, props.dateSerializationFormat);
    dataAccessors.resources = createExpressions(props.resources);
    return dataAccessors
};
export var createTimeZoneCalculator = currentTimeZone => new TimeZoneCalculator({
    getClientOffset: date => timeZoneUtils.getClientTimezoneOffset(date),
    getCommonOffset: date => timeZoneUtils.calculateTimezoneByValue(currentTimeZone, date),
    getAppointmentOffset: (date, appointmentTimezone) => timeZoneUtils.calculateTimezoneByValue(appointmentTimezone, date)
});
export var filterAppointments = (appointmentsConfig, dataItems, dataAccessors, timeZoneCalculator, loadedResources, viewDataProvider) => {
    if (!appointmentsConfig) {
        return []
    }
    var filterOptions = {
        resources: appointmentsConfig.resources,
        startDayHour: appointmentsConfig.startDayHour,
        endDayHour: appointmentsConfig.endDayHour,
        appointmentDuration: appointmentsConfig.cellDurationInMinutes,
        showAllDayPanel: appointmentsConfig.showAllDayPanel,
        supportAllDayRow: appointmentsConfig.supportAllDayRow,
        firstDayOfWeek: appointmentsConfig.firstDayOfWeek,
        viewType: appointmentsConfig.viewType,
        viewDirection: "vertical",
        dateRange: appointmentsConfig.dateRange,
        groupCount: appointmentsConfig.groupCount,
        timeZoneCalculator: timeZoneCalculator,
        dataSource: void 0,
        dataAccessors: dataAccessors,
        loadedResources: loadedResources,
        viewDataProvider: viewDataProvider
    };
    var preparedDataItems = getPreparedDataItems(dataItems, dataAccessors, appointmentsConfig.cellDurationInMinutes, timeZoneCalculator);
    var filterStrategy = appointmentsConfig.isVirtualScrolling ? new AppointmentFilterVirtualStrategy(filterOptions) : new AppointmentFilterBaseStrategy(filterOptions);
    var filteredItems = filterStrategy.filter(preparedDataItems);
    return filteredItems
};
export var isViewDataProviderConfigValid = (viewDataProviderConfig, currentViewOptions) => {
    if (!viewDataProviderConfig) {
        return false
    }
    var result = true;
    Object.entries(viewDataProviderConfig).forEach(_ref => {
        var [key, value] = _ref;
        if (value !== currentViewOptions[key]) {
            result = false
        }
    });
    return result
};
